package de.fitko.fitconnect.client.factory;

import de.fitko.fitconnect.api.config.*;
import org.junit.jupiter.api.Test;

import static de.fitko.fitconnect.api.config.UsedEnvironment.DEV;
import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertThrows;

public class ClientFactoryTest {

    @Test
    public void testMissingConfiguration() {
        assertThrows(IllegalStateException.class, () -> ClientFactory.senderClient());
        assertThrows(IllegalStateException.class, () -> ClientFactory.subscriberClient());
    }

    @Test
    public void testSenderClientConstruction() {

        final var devEnvironment = new Environment();
        devEnvironment.setAuthBaseUrl("https://auth");

        final var environments = new Environments();
        environments.setDev(devEnvironment);

        final var sender = new Sender();
        sender.setClientSecret("123");
        sender.setClientSecret("abc");

        final var resourcePaths = new ResourcePaths();
        resourcePaths.setAuthTokenPath("/token");

        final var senderConfig = new ApplicationConfig();
        senderConfig.setHttpProxyHost("https://proxy.fitco.de");
        senderConfig.setHttpProxyPort(0);
        senderConfig.setEnvironments(environments);
        senderConfig.setSender(sender);
        senderConfig.setUsedEnvironment(DEV);
        senderConfig.setResourcePaths(resourcePaths);

        assertNotNull(ClientFactory.senderClient(senderConfig));
    }

    @Test
    public void testSubscriberClientConstruction() {
        final var devEnvironment = new Environment();
        devEnvironment.setAuthBaseUrl("https://auth");

        final var environments = new Environments();
        environments.setDev(devEnvironment);

        final var resourcePaths = new ResourcePaths();
        resourcePaths.setAuthTokenPath("/token");

        final var subscriber = new Subscriber();
        subscriber.setClientSecret("123");
        subscriber.setClientSecret("abc");
        subscriber.setPrivateDecryptionKeyPath("src/test/resources/private_decryption_test_key.json");
        subscriber.setPrivateSigningKeyPath("src/test/resources/private_test_signing_key.json");
        subscriber.setMetadataSchemaPath("src/test/resources/metadata_schema.json");

        final var subscriberConfig = new ApplicationConfig();
        subscriberConfig.setHttpProxyHost("https://proxy.fitco.de");
        subscriberConfig.setHttpProxyPort(0);
        subscriberConfig.setEnvironments(environments);
        subscriberConfig.setSubscriber(subscriber);
        subscriberConfig.setUsedEnvironment(DEV);
        subscriberConfig.setResourcePaths(resourcePaths);

        assertNotNull(ClientFactory.subscriberClient(subscriberConfig));
    }
}