package de.fitko.fitconnect.core.util;

import java.util.function.Supplier;

public class Preconditions {

    /**
     * Throws a supplied (runtime) exception if the expression evaluates to false
     *
     * @param argumentName name of the argument to check
     * @param expression expression to evaluate
     * @param exceptionSupplier supplier for the exception
     */
    public static void checkArgument(final String argumentName, final boolean expression, final Supplier<? extends RuntimeException> exceptionSupplier) {
        if (!expression) {
            throw exceptionSupplier.get();
        }
    }
    /**
     * Throws an IllegalStateException if the expression evaluates to false
     *
     * @param argumentName name of the argument to check
     * @param expression expression to evaluate
     */
    public static void checkArgument(final String argumentName, final boolean expression) {
       checkArgument(argumentName, expression, () -> new IllegalStateException("Parameter " + argumentName + " must not be null"));
    }

    /**
     * Throws an IllegalStateException if the argument is null
     *
     * @param argumentName name of the argument to check
     * @param argument argument to check
     */
    public static void checkNotNull(final String argumentName, final Object argument) {
        checkArgument(argumentName, argument != null, () -> new IllegalStateException("Parameter " + argumentName + " must not be null"));
    }
}
