package de.fitko.fitconnect.core;

import com.github.tomakehurst.wiremock.WireMockServer;
import com.github.tomakehurst.wiremock.client.WireMock;
import de.fitko.fitconnect.api.config.*;

import static com.github.tomakehurst.wiremock.core.WireMockConfiguration.wireMockConfig;

public abstract class RestEndpointBase {

    public static WireMockServer wireMockServer;

    static {
        wireMockServer = new WireMockServer(wireMockConfig().dynamicPort());
        wireMockServer.start();
        WireMock.configureFor("localhost", wireMockServer.port());
    }

    protected ApplicationConfig getTestConfig(final String fakeBaseUrl) {
        final var testEnv = new Environment();
        testEnv.setSubmissionBaseUrl(fakeBaseUrl);
        testEnv.setAuthBaseUrl(fakeBaseUrl);

        final var environments = new Environments();
        environments.setTest(testEnv);

        final var resourcePaths = new ResourcePaths();
        resourcePaths.setAuthTokenPath("/token");
        resourcePaths.setDestinationPath("/v1/destinations/{destinationId}");
        resourcePaths.setDestinationKeyPath("/v1/destinations/{destinationId}/keys/{kid}");
        resourcePaths.setEventLogPath("/v1/cases/{caseId}/events");
        resourcePaths.setSubmissionsPath("/v1/submissions");
        resourcePaths.setSubmissionPath("/v1/submissions/{submissionId}");
        resourcePaths.setSubmissionAttachmentPath("/v1/submissions/{submissionId}/attachments/{attachmentId}");

        final var config = new ApplicationConfig();
        config.setUsedEnvironment(UsedEnvironment.TEST);
        config.setEnvironments(environments);
        config.setResourcePaths(resourcePaths);

        return config;
    }

}
